# swaystatus

Generates a status line for [swaybar][swaybar-protocol].

## Installation

### Python

Install as a python package:

```sh
pip install swaystatus
```

### Repository

To install in the default location (`/usr/local`):

```sh
sudo ./scripts/install
```

To install in a different location:

```sh
PREFIX=/usr sudo ./scripts/install
```

## Testing

To run the included tests:

```sh
./scripts/test
```

[swaybar-protocol]: https://man.archlinux.org/man/swaybar-protocol.7
